Pipeline
========
.. automodule:: graspologic.pipeline

GraphBuilder
------------
.. autoclass:: GraphBuilder

Embed
-----
.. automodule:: graspologic.pipeline.embed
.. autoclass:: graspologic.pipeline.embed.embeddings.Embeddings
.. autofunction:: graspologic.pipeline.embed.adjacency_spectral_embedding
.. autofunction:: graspologic.pipeline.embed.laplacian_spectral_embedding
.. autofunction:: graspologic.pipeline.embed.omnibus_embedding_pairwise
